Learn R Programming

EnrichmentBrowser (version 1.0.3)

de.ana: Differential expression analysis between two sample groups

Description

The function carries out a differential expression analysis between two sample groups. Resulting fold changes and t-test derived p-values for each feature are appended to the fData slot. Raw p-values are corrected for multiple testing using the method from Benjamini and Hochberg.

Usage

de.ana(eset)

Arguments

eset
An object of class 'ExpressionSet'

Value

An object of ExpressionSet-class with measures of differential expression annotated in the fData slot.

See Also

ExpressionSet-class, eBayes, p.adjust

Examples

Run this code
    # reading the expression data from file
    exprs.file <- system.file("extdata/ALL_exprs.tab", package="EnrichmentBrowser")
    pdat.file <- system.file("extdata/ALL_pData.tab", package="EnrichmentBrowser")
    fdat.file <- system.file("extdata/ALL_fData.tab", package="EnrichmentBrowser")
    eset <- read.eset(exprs.file, pdat.file, fdat.file)
    eset <- de.ana(eset)
    head(fData(eset))

Run the code above in your browser using DataLab